==> jc-1.4.0.tar.gz: gnu/regexp/RE__24CharUnit.h <==
// final class gnu.regexp.RE$CharUnit

// class file dependencies
// @dep_class 2ddd0e04bb318ae9 gnu_regexp_RE__24CharUnit
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_RE__24CharUnit_H_
#define _JC_gnu_regexp_RE__24CharUnit_H_

// Forward structure declarations
struct _jc_gnu_regexp_RE__241$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_regexp_RE__24CharUnit$sub_refs	_jc_gnu_regexp_RE__24CharUnit$sub_refs;
typedef struct _jc_gnu_regexp_RE__24CharUnit$sub_nonrefs	_jc_gnu_regexp_RE__24CharUnit$sub_nonrefs;
typedef struct _jc_gnu_regexp_RE__24CharUnit$refs	_jc_gnu_regexp_RE__24CharUnit$refs;
typedef struct _jc_gnu_regexp_RE__24CharUnit$nonrefs	_jc_gnu_regexp_RE__24CharUnit$nonrefs;
typedef struct _jc_gnu_regexp_RE__24CharUnit$object	_jc_gnu_regexp_RE__24CharUnit$object;

typedef const struct _jc_gnu_regexp_RE__24CharUnit$vmethods	_jc_gnu_regexp_RE__24CharUnit$vmethods;
typedef const struct _jc_gnu_regexp_RE__24CharUnit$vtable	_jc_gnu_regexp_RE__24CharUnit$vtable;
typedef const struct _jc_gnu_regexp_RE__24CharUnit$vtype	_jc_gnu_regexp_RE__24CharUnit$vtype;

// Constructors
extern void _jc_gnu_regexp_RE__24CharUnit$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_regexp_RE__24CharUnit$object *);
extern void _jc_gnu_regexp_RE__24CharUnit$method$_init$3727815867c797ab(_jc_env *, struct _jc_gnu_regexp_RE__24CharUnit$object *, struct _jc_gnu_regexp_RE__241$object *);

// Virtual methods structure
struct _jc_gnu_regexp_RE__24CharUnit$vmethods {
};

// Vtable
struct _jc_gnu_regexp_RE__24CharUnit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_RE__24CharUnit$vmethods	gnu_regexp_RE__24CharUnit;
};

// Vtype
struct _jc_gnu_regexp_RE__24CharUnit$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RE__24CharUnit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RE__24CharUnit$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RE__24CharUnit$refs {
    _jc_gnu_regexp_RE__24CharUnit$sub_refs	gnu_regexp_RE__24CharUnit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RE__24CharUnit$sub_nonrefs {
	jchar	ch;
	jboolean	bk;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RE__24CharUnit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_RE__24CharUnit$sub_nonrefs	gnu_regexp_RE__24CharUnit;
};

// Object instance structure
struct _jc_gnu_regexp_RE__24CharUnit$object {
	_jc_gnu_regexp_RE__24CharUnit$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RE__24CharUnit$vtype	*vtype;
	_jc_gnu_regexp_RE__24CharUnit$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RE__24CharUnit$vtype _jc_gnu_regexp_RE__24CharUnit$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RE__24CharUnit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RE__24CharUnit$class_object;

#endif	/* _JC_gnu_regexp_RE__24CharUnit_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/RE__24CharUnit.h <==
// final class gnu.regexp.RE$CharUnit

// class file dependencies
// @dep_class 2ddd0e04bb318ae9 gnu_regexp_RE__24CharUnit
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_RE__24CharUnit_H_
#define _JC_gnu_regexp_RE__24CharUnit_H_

// Forward structure declarations
struct _jc_gnu_regexp_RE__241$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_regexp_RE__24CharUnit$sub_refs	_jc_gnu_regexp_RE__24CharUnit$sub_refs;
typedef struct _jc_gnu_regexp_RE__24CharUnit$sub_nonrefs	_jc_gnu_regexp_RE__24CharUnit$sub_nonrefs;
typedef struct _jc_gnu_regexp_RE__24CharUnit$refs	_jc_gnu_regexp_RE__24CharUnit$refs;
typedef struct _jc_gnu_regexp_RE__24CharUnit$nonrefs	_jc_gnu_regexp_RE__24CharUnit$nonrefs;
typedef struct _jc_gnu_regexp_RE__24CharUnit$object	_jc_gnu_regexp_RE__24CharUnit$object;

typedef const struct _jc_gnu_regexp_RE__24CharUnit$vmethods	_jc_gnu_regexp_RE__24CharUnit$vmethods;
typedef const struct _jc_gnu_regexp_RE__24CharUnit$vtable	_jc_gnu_regexp_RE__24CharUnit$vtable;
typedef const struct _jc_gnu_regexp_RE__24CharUnit$vtype	_jc_gnu_regexp_RE__24CharUnit$vtype;

// Constructors
extern void _jc_gnu_regexp_RE__24CharUnit$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_regexp_RE__24CharUnit$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_regexp_RE__24CharUnit$method$_init$3727815867c797ab(_jc_env *, struct _jc_gnu_regexp_RE__24CharUnit$object *, struct _jc_gnu_regexp_RE__241$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_regexp_RE__24CharUnit$vmethods {
};

// Vtable
struct _jc_gnu_regexp_RE__24CharUnit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_RE__24CharUnit$vmethods	gnu_regexp_RE__24CharUnit;
};

// Vtype
struct _jc_gnu_regexp_RE__24CharUnit$vtype {
	_jc_type			type;
	_jc_gnu_regexp_RE__24CharUnit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_RE__24CharUnit$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_regexp_RE__24CharUnit$refs {
    _jc_gnu_regexp_RE__24CharUnit$sub_refs	gnu_regexp_RE__24CharUnit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_RE__24CharUnit$sub_nonrefs {
	jchar	ch;
	jboolean	bk;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_RE__24CharUnit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_RE__24CharUnit$sub_nonrefs	gnu_regexp_RE__24CharUnit;
};

// Object instance structure
struct _jc_gnu_regexp_RE__24CharUnit$object {
	_jc_gnu_regexp_RE__24CharUnit$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_RE__24CharUnit$vtype	*vtype;
	_jc_gnu_regexp_RE__24CharUnit$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_RE__24CharUnit$vtype _jc_gnu_regexp_RE__24CharUnit$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_RE__24CharUnit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_RE__24CharUnit$class_object;

#endif	/* _JC_gnu_regexp_RE__24CharUnit_H_ */
